<?php
/**
 *
 * Adds custom Block Patterns to the post/page editor.
 *
 * see: https://developer.wordpress.org/block-editor/developers/block-api/block-patterns/
 *
 * @package Cordero
 */


register_block_pattern_category(
	'cordero-theme',
	array( 'label' => __( 'Cordero', 'cordero' ) )
);


register_block_pattern(
	'cordero/hero-with-buttons-1',
	array(
		'title'			=> __( 'Hero with Two Buttons', 'cordero' ),
		'description'	=> _x( 'A large full width hero cover with a title, sub-title, and two buttons.', 'Block pattern description', 'cordero' ),

		'content'		=> '<!-- wp:cover {"url":"' . esc_url( get_theme_file_uri( 'images/cover-background.jpg' ) ) . '","hasParallax":true,"dimRatio":80,"gradient":"cool-to-warm-spectrum","align":"full"} -->
<div class="wp-block-cover alignfull has-background-dim-80 has-background-dim has-parallax has-background-gradient" style="background-image:url(' . esc_url( get_theme_file_uri( 'images/cover-background.jpg' ) ) . ')"><span aria-hidden="true" class="wp-block-cover__gradient-background has-cool-to-warm-spectrum-gradient-background"></span><div class="wp-block-cover__inner-container"><!-- wp:spacer {"height":40} -->
<div style="height:40px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:heading {"align":"center"} -->
<h2 class="has-text-align-center">' . _x( 'Example Heading', 'Theme starter content', 'cordero' ) . '</h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","fontSize":"medium"} -->
<p class="has-text-align-center has-medium-font-size">' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":40} -->
<div style="height:40px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button {"backgroundColor":"accent-color2"} -->
<div class="wp-block-button"><a class="wp-block-button__link has-accent-color-2-background-color has-background">' . _x( 'Read More', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button -->

<!-- wp:button {"customBackgroundColor":"#ffffff","textColor":"accent-color2","className":"is-style-fill"} -->
<div class="wp-block-button is-style-fill"><a class="wp-block-button__link has-accent-color-2-color has-text-color has-background" style="background-color:#ffffff">' . _x( 'Get In Touch', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div></div>
<!-- /wp:cover -->',

		'viewportWidth'	=> 1000,
		'categories'	=> array( 'cordero-theme' ),
	)
);


register_block_pattern(
	'cordero/featured-services-1',
	array(
		'title'			=> __( 'Featured Services', 'cordero' ),
		'description'	=> _x( 'Three featured services.', 'Block pattern description', 'cordero' ),

		'content'		=> '<!-- wp:group -->
<div class="wp-block-group"><div class="wp-block-group__inner-container">

<!-- wp:heading {"align":"center"} -->
<h2 class="has-text-align-center">' . _x( 'Example Heading', 'Theme starter content', 'cordero' ) . '</h2>
<!-- /wp:heading -->

<!-- wp:spacer {"height":40} -->
<div style="height:40px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:columns {"className":"featured-style-1"} -->
<div class="wp-block-columns featured-style-1"><!-- wp:column -->
<div class="wp-block-column"><!-- wp:image {"align":"center","sizeSlug":"cordero-featured-service","className":"is-style-rounded"} -->
<div class="wp-block-image is-style-rounded"><figure class="aligncenter size-cordero-featured-service"><img src="' . esc_url( get_theme_file_uri( 'images/icon-settings-light.png' ) ) . '" alt="" class=""/></figure></div>
<!-- /wp:image -->

<!-- wp:heading {"align":"center","level":3,"textColor":"accent-color2"} -->
<h3 class="has-text-align-center has-accent-color-2-color has-text-color">' . _x( 'Feature One', 'Theme starter content', 'cordero' ) . '</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","textColor":"accent-color2"} -->
<p class="has-text-align-center has-accent-color-2-color has-text-color">' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button -->
<div class="wp-block-button"><a class="wp-block-button__link">' . _x( 'Read More', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:image {"align":"center","sizeSlug":"cordero-featured-service","className":"is-style-rounded"} -->
<div class="wp-block-image is-style-rounded"><figure class="aligncenter size-cordero-featured-service"><img src="' . esc_url( get_theme_file_uri( 'images/icon-camera-light.png' ) ) . '" alt="" class=""/></figure></div>
<!-- /wp:image -->

<!-- wp:heading {"align":"center","level":3,"textColor":"accent-color2"} -->
<h3 class="has-text-align-center has-accent-color-2-color has-text-color">' . _x( 'Feature Two', 'Theme starter content', 'cordero' ) . '</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","textColor":"accent-color2"} -->
<p class="has-text-align-center has-accent-color-2-color has-text-color">' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button -->
<div class="wp-block-button"><a class="wp-block-button__link">' . _x( 'Read More', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:image {"align":"center","sizeSlug":"cordero-featured-service","className":"is-style-rounded"} -->
<div class="wp-block-image is-style-rounded"><figure class="aligncenter size-cordero-featured-service"><img src="' . esc_url( get_theme_file_uri( 'images/icon-rocket-light.png' ) ) . '" alt="" class=""/></figure></div>
<!-- /wp:image -->

<!-- wp:heading {"align":"center","level":3,"textColor":"accent-color2"} -->
<h3 class="has-text-align-center has-accent-color-2-color has-text-color">' . _x( 'Feature Three', 'Theme starter content', 'cordero' ) . '</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","textColor":"accent-color2"} -->
<p class="has-text-align-center has-accent-color-2-color has-text-color">' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button -->
<div class="wp-block-button"><a class="wp-block-button__link">' . _x( 'Read More', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->

</div></div>
<!-- /wp:group -->',

		'viewportWidth'	=> 1400,
		'categories'	=> array( 'cordero-theme' ),
	)
);


register_block_pattern(
	'cordero/featured-services-1-overlap',
	array(
		'title'			=> __( 'Cover and Overlapped Featured Services', 'cordero' ),
		'description'	=> _x( 'A full width cover block and three overlapped featured services.', 'Block pattern description', 'cordero' ),

		'content'		=> '<!-- wp:group {"align":"full"} -->
<div class="wp-block-group alignfull"><div class="wp-block-group__inner-container">

<!-- wp:cover {"url":"' . esc_url( get_theme_file_uri( 'images/cover-background.jpg' ) ) . '","hasParallax":true,"dimRatio":80,"gradient":"cool-to-warm-spectrum","align":"full","className":"has-overlap"} -->
<div class="wp-block-cover alignfull has-background-dim-80 has-background-dim has-parallax has-background-gradient has-overlap" style="background-image:url(' . esc_url( get_theme_file_uri( 'images/cover-background.jpg' ) ) . ')"><span aria-hidden="true" class="wp-block-cover__gradient-background has-cool-to-warm-spectrum-gradient-background"></span><div class="wp-block-cover__inner-container">

<!-- wp:heading {"align":"center"} -->
<h2 class="has-text-align-center">' . _x( 'Example Heading', 'Theme starter content', 'cordero' ) . '</h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":60} -->
<div style="height:60px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer --></div></div>
<!-- /wp:cover -->

<!-- wp:columns {"className":"featured-style-1 overlap"} -->
<div class="wp-block-columns featured-style-1 overlap"><!-- wp:column -->
<div class="wp-block-column"><!-- wp:image {"align":"center","sizeSlug":"cordero-featured-service","className":"is-style-rounded"} -->
<div class="wp-block-image is-style-rounded"><figure class="aligncenter size-cordero-featured-service"><img src="' . esc_url( get_theme_file_uri( 'images/icon-settings-light.png' ) ) . '" alt="" class=""/></figure></div>
<!-- /wp:image -->

<!-- wp:heading {"align":"center","level":3,"textColor":"accent-color2"} -->
<h3 class="has-text-align-center has-accent-color-2-color has-text-color">' . _x( 'Feature One', 'Theme starter content', 'cordero' ) . '</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","textColor":"accent-color2"} -->
<p class="has-text-align-center has-accent-color-2-color has-text-color">' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button -->
<div class="wp-block-button"><a class="wp-block-button__link">' . _x( 'Read More', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:image {"align":"center","sizeSlug":"cordero-featured-service","className":"is-style-rounded"} -->
<div class="wp-block-image is-style-rounded"><figure class="aligncenter size-cordero-featured-service"><img src="' . esc_url( get_theme_file_uri( 'images/icon-camera-light.png' ) ) . '" alt="" class=""/></figure></div>
<!-- /wp:image -->

<!-- wp:heading {"align":"center","level":3,"textColor":"accent-color2"} -->
<h3 class="has-text-align-center has-accent-color-2-color has-text-color">' . _x( 'Feature Two', 'Theme starter content', 'cordero' ) . '</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","textColor":"accent-color2"} -->
<p class="has-text-align-center has-accent-color-2-color has-text-color">' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button -->
<div class="wp-block-button"><a class="wp-block-button__link">' . _x( 'Read More', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:image {"align":"center","sizeSlug":"cordero-featured-service","className":"is-style-rounded"} -->
<div class="wp-block-image is-style-rounded"><figure class="aligncenter size-cordero-featured-service"><img src="' . esc_url( get_theme_file_uri( 'images/icon-rocket-light.png' ) ) . '" alt="" class=""/></figure></div>
<!-- /wp:image -->

<!-- wp:heading {"align":"center","level":3,"textColor":"accent-color2"} -->
<h3 class="has-text-align-center has-accent-color-2-color has-text-color">' . _x( 'Feature Three', 'Theme starter content', 'cordero' ) . '</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","textColor":"accent-color2"} -->
<p class="has-text-align-center has-accent-color-2-color has-text-color">' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button -->
<div class="wp-block-button"><a class="wp-block-button__link">' . _x( 'Read More', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->

</div></div>
<!-- /wp:group -->',

		'viewportWidth'	=> 1400,
		'categories'	=> array( 'cordero-theme' ),
	)
);


register_block_pattern(
	'cordero/pricing-table-1',
	array(
		'title'			=> __( 'Pricing Table', 'cordero' ),
		'description'	=> _x( 'A three column pricing table.', 'Block pattern description', 'cordero' ),

		'content'		=> '<!-- wp:columns {"className":"pricing-table has-featured"} -->
<div class="wp-block-columns pricing-table has-featured"><!-- wp:column -->
<div class="wp-block-column"><!-- wp:heading {"align":"center","level":3,"textColor":"accent-color"} -->
<h3 class="has-text-align-center has-accent-color-color has-text-color">' . _x( 'ITEM ONE', 'Theme starter content', 'cordero' ) . '</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size">' . _x( '$', 'Theme starter content', 'cordero' ) . '<strong><span class="has-inline-color has-accent-color-2-color">' . _x( '49', 'Theme starter content', 'cordero' ) . '</span></strong> <sub>' . _x( '/year', 'Theme starter content', 'cordero' ) . '</sub></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">' . _x( '1 User Account', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:list -->
<ul><li>' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Dictum tellus eleifend varius eros', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Cubilia rutrum consequat libero, potenti', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Vivamus dictum scelerisque porta', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Vestibulum fermentum mollis duis enim', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Primis tristique convallis sociosqu diam', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Commodo tempus accumsan justo', 'Theme starter content', 'cordero' ) . '</li></ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button -->
<div class="wp-block-button"><a class="wp-block-button__link">' . _x( 'Click Here', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column {"className":"is-featured"} -->
<div class="wp-block-column is-featured"><!-- wp:heading {"align":"center","level":3,"textColor":"accent-color"} -->
<h3 class="has-text-align-center has-accent-color-color has-text-color">' . _x( 'ITEM TWO', 'Theme starter content', 'cordero' ) . '</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size">' . _x( '$', 'Theme starter content', 'cordero' ) . '<strong><span class="has-inline-color has-accent-color-2-color">' . _x( '99', 'Theme starter content', 'cordero' ) . '</span></strong> <sub>' . _x( '/year', 'Theme starter content', 'cordero' ) . '</sub></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">' . _x( '5 User Accounts', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:list -->
<ul><li>' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Dictum tellus eleifend varius eros', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Cubilia rutrum consequat libero, potenti', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Vivamus dictum scelerisque porta', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Vestibulum fermentum mollis duis enim', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Primis tristique convallis sociosqu diam', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Commodo tempus accumsan justo', 'Theme starter content', 'cordero' ) . '</li></ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button -->
<div class="wp-block-button"><a class="wp-block-button__link">' . _x( 'Click Here', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:heading {"align":"center","level":3,"textColor":"accent-color"} -->
<h3 class="has-text-align-center has-accent-color-color has-text-color">' . _x( 'ITEM THREE', 'Theme starter content', 'cordero' ) . '</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size">' . _x( '$', 'Theme starter content', 'cordero' ) . '<strong><span class="has-inline-color has-accent-color-2-color">' . _x( '179', 'Theme starter content', 'cordero' ) . '</span></strong> <sub>' . _x( '/year', 'Theme starter content', 'cordero' ) . '</sub></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">' . _x( '50 User Accounts', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:list -->
<ul><li>' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Dictum tellus eleifend varius eros', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Cubilia rutrum consequat libero, potenti', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Vivamus dictum scelerisque porta', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Vestibulum fermentum mollis duis enim', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Primis tristique convallis sociosqu diam', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Commodo tempus accumsan justo', 'Theme starter content', 'cordero' ) . '</li></ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button -->
<div class="wp-block-button"><a class="wp-block-button__link">' . _x( 'Click Here', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->',

		'viewportWidth'	=> 1400,
		'categories'	=> array( 'cordero-theme' ),
	)
);


register_block_pattern(
	'cordero/pricing-table-1-overlap',
	array(
		'title'			=> __( 'Cover and Overlapped Pricing Table', 'cordero' ),
		'description'	=> _x( 'A full width cover block and three column overlapped pricing table.', 'Block pattern description', 'cordero' ),

		'content'		=> '<!-- wp:group {"align":"full"} -->
<div class="wp-block-group alignfull"><div class="wp-block-group__inner-container">

<!-- wp:cover {"url":"' . esc_url( get_theme_file_uri( 'images/cover-background.jpg' ) ) . '","hasParallax":true,"dimRatio":80,"gradient":"cool-to-warm-spectrum","align":"full","className":"has-overlap"} -->
<div class="wp-block-cover alignfull has-background-dim-80 has-background-dim has-parallax has-background-gradient has-overlap" style="background-image:url(' . esc_url( get_theme_file_uri( 'images/cover-background.jpg' ) ) . ')"><span aria-hidden="true" class="wp-block-cover__gradient-background has-cool-to-warm-spectrum-gradient-background"></span><div class="wp-block-cover__inner-container">

<!-- wp:heading {"align":"center"} -->
<h2 class="has-text-align-center">' . _x( 'Example Heading', 'Theme starter content', 'cordero' ) . '</h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

</div></div>
<!-- /wp:cover -->

<!-- wp:columns {"className":"pricing-table has-featured overlap"} -->
<div class="wp-block-columns pricing-table has-featured overlap"><!-- wp:column -->
<div class="wp-block-column"><!-- wp:heading {"align":"center","level":3,"textColor":"accent-color"} -->
<h3 class="has-text-align-center has-accent-color-color has-text-color">' . _x( 'ITEM ONE', 'Theme starter content', 'cordero' ) . '</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size">' . _x( '$', 'Theme starter content', 'cordero' ) . '<strong><span class="has-inline-color has-accent-color-2-color">' . _x( '49', 'Theme starter content', 'cordero' ) . '</span></strong> <sub>' . _x( '/year', 'Theme starter content', 'cordero' ) . '</sub></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">' . _x( '1 User Account', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:list -->
<ul><li>' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Dictum tellus eleifend varius eros', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Cubilia rutrum consequat libero, potenti', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Vivamus dictum scelerisque porta', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Vestibulum fermentum mollis duis enim', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Primis tristique convallis sociosqu diam', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Commodo tempus accumsan justo', 'Theme starter content', 'cordero' ) . '</li></ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button -->
<div class="wp-block-button"><a class="wp-block-button__link">' . _x( 'Click Here', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column {"className":"is-featured"} -->
<div class="wp-block-column is-featured"><!-- wp:heading {"align":"center","level":3,"textColor":"accent-color"} -->
<h3 class="has-text-align-center has-accent-color-color has-text-color">' . _x( 'ITEM TWO', 'Theme starter content', 'cordero' ) . '</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size">' . _x( '$', 'Theme starter content', 'cordero' ) . '<strong><span class="has-inline-color has-accent-color-2-color">' . _x( '99', 'Theme starter content', 'cordero' ) . '</span></strong> <sub>' . _x( '/year', 'Theme starter content', 'cordero' ) . '</sub></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">' . _x( '5 User Accounts', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:list -->
<ul><li>' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Dictum tellus eleifend varius eros', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Cubilia rutrum consequat libero, potenti', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Vivamus dictum scelerisque porta', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Vestibulum fermentum mollis duis enim', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Primis tristique convallis sociosqu diam', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Commodo tempus accumsan justo', 'Theme starter content', 'cordero' ) . '</li></ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button -->
<div class="wp-block-button"><a class="wp-block-button__link">' . _x( 'Click Here', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:heading {"align":"center","level":3,"textColor":"accent-color"} -->
<h3 class="has-text-align-center has-accent-color-color has-text-color">' . _x( 'ITEM THREE', 'Theme starter content', 'cordero' ) . '</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size">' . _x( '$', 'Theme starter content', 'cordero' ) . '<strong><span class="has-inline-color has-accent-color-2-color">' . _x( '179', 'Theme starter content', 'cordero' ) . '</span></strong> <sub>' . _x( '/year', 'Theme starter content', 'cordero' ) . '</sub></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">' . _x( '50 User Accounts', 'Theme starter content', 'cordero' ) . '</p>
<!-- /wp:paragraph -->

<!-- wp:list -->
<ul><li>' . _x( 'Lorem ipsum dolor sit amet consectetur', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Dictum tellus eleifend varius eros', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Cubilia rutrum consequat libero, potenti', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Vivamus dictum scelerisque porta', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Vestibulum fermentum mollis duis enim', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Primis tristique convallis sociosqu diam', 'Theme starter content', 'cordero' ) . '</li><li>' . _x( 'Commodo tempus accumsan justo', 'Theme starter content', 'cordero' ) . '</li></ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"align":"center"} -->
<div class="wp-block-buttons aligncenter"><!-- wp:button -->
<div class="wp-block-button"><a class="wp-block-button__link">' . _x( 'Click Here', 'Theme starter content', 'cordero' ) . '</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->

</div></div>
<!-- /wp:group -->',

		'viewportWidth'	=> 1400,
		'categories'	=> array( 'cordero-theme' ),
	)
);
